@@ -23,7 +23,7 @@ class CompositeApplicationConfiguration(BaseApplicationConfiguration):
     def get_value(self, key):
         for inner in self._inners:
             value = inner.get_value(key)
-            if value:
+            if value is not None:
                 return value
         return None
     
